# NUMiner

NUMiner is a Python library for creating training image for Handwritten Text Recognition or HTR. It uses prebuilt

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install numiner.

```bash
pip install numiner
```

## Usage

## Contributing

Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License

[MIT](https://choosealicense.com/licenses/mit/)
